<?php // phpcs:ignore WordPress.Files.FileName.NotHyphenatedLowercase
/**
 * CSS Rules.
 *
 * @package PressBook_Media
 */

/**
 * Generate dynamic CSS rules for theme.
 */
class PressBook_Media_CSSRules extends PressBook\CSSRules {
	/**
	 * Top Info Background Color.
	 *
	 * @param string $value Color value.
	 * @return array
	 */
	public static function top_info_bg_color( $value ) {
		return array(
			'.top-info' => array(
				'background' => array(
					'value' => PressBook\Options\Sanitizer::sanitize_alpha_color( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}

	/**
	 * Top Info Text Color.
	 *
	 * @param string $value Color value.
	 * @return array
	 */
	public static function top_info_color( $value ) {
		return array(
			'.top-info' => array(
				'color' => array(
					'value' => sanitize_hex_color( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}

	/**
	 * Top Info Font Weight.
	 *
	 * @param string $value Font weight value.
	 * @return array
	 */
	public static function top_info_font_wgt( $value ) {
		return array(
			'.top-info-contact span' => array(
				'font-weight' => array(
					'value' => absint( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}

	/**
	 * Top Info Button Background Color.
	 *
	 * @param string $value Color value.
	 * @return array
	 */
	public static function top_info_button_bg_color( $value ) {
		return array(
			'.top-info-buttons .top-info-button' => array(
				'background' => array(
					'value' => PressBook\Options\Sanitizer::sanitize_alpha_color( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}

	/**
	 * Top Info Button Border Color.
	 *
	 * @param string $value Color value.
	 * @return array
	 */
	public static function top_info_button_border_color( $value ) {
		return array(
			'.top-info-buttons .top-info-button' => array(
				'border-color' => array(
					'value' => PressBook\Options\Sanitizer::sanitize_alpha_color( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}

	/**
	 * Top Info Button Text Color.
	 *
	 * @param string $value Color value.
	 * @return array
	 */
	public static function top_info_button_color( $value ) {
		return array(
			'.top-info-buttons .top-info-button' => array(
				'color' => array(
					'value' => sanitize_hex_color( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}

	/**
	 * Primary Navbar Background Color.
	 *
	 * @param string $value Color value.
	 * @return array
	 */
	public static function primary_navbar_bg_color( $value ) {
		return array(
			'.primary-navbar,.main-navigation ul ul' => array(
				'background' => array(
					'value' => PressBook\Options\Sanitizer::sanitize_alpha_color( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}

	/**
	 * Primary Navbar Hover Background Color.
	 *
	 * @param string $value Color value.
	 * @return array
	 */
	public static function primary_navbar_hover_bg_color( $value ) {
		return array(
			'.main-navigation .menu .current-menu-ancestor>a,.main-navigation .menu .current-menu-item>a,.main-navigation .menu .current-menu-parent>a,.main-navigation .main-navigation-arrow-btn:active,.main-navigation .main-navigation-arrow-btn:hover,.main-navigation a:active,.main-navigation a:focus,.main-navigation a:hover,.main-navigation li.focus>.main-navigation-arrow-btn,.main-navigation:not(.toggled) li:hover>.main-navigation-arrow-btn' => array(
				'background' => array(
					'value' => PressBook\Options\Sanitizer::sanitize_alpha_color( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}

	/**
	 * Footer Credit Link Color.
	 *
	 * @param string $value Color value.
	 * @return array
	 */
	public static function footer_credit_link_color( $value ) {
		return array(
			'.copyright-text a,.footer-widgets .widget li::before' => array(
				'color' => array(
					'value' => sanitize_hex_color( $value ),
					'place' => '_PLACE',
				),
			),
			'.footer-widgets .widget .widget-title::after,.footer-widgets .widget_block h1:first-child::after,.footer-widgets .widget_block h2:first-child::after,.footer-widgets .widget_block h3:first-child::after' => array(
				'background' => array(
					'value' => sanitize_hex_color( $value ),
					'place' => '_PLACE',
				),
			),
		);
	}
}
